# _DevOps Course Gaming Project_
## To get the full experience you will need two things:
### 1a. Installing the gameplay using 'pip install gbwog.panel'
### 1b. Calling it with 'pycommand (python in Windows and python/python3 in Linux) -m gbwog.panel
### 2a. Installing the score site using 'pip install gbwog.website'
### 2b. Run the site simultaneously with the game using another process of 'pycommand -m gbwog.website'
